@@ -64,6 +64,15 @@ struct _FontViewModelItem
     int face_index;
 };
 
+enum {
+  PROP_0,
+  PROP_FONT_NAME,
+  PROP_FONT_PREVIEW_TEXT,
+  N_PROPS
+};
+
+static GParamSpec *properties [N_PROPS];
+
 G_DEFINE_TYPE (FontViewModelItem, font_view_model_item, G_TYPE_OBJECT)
 
 static void
@@ -72,16 +81,50 @@ font_view_model_item_finalize (GObject *obj)
     FontViewModelItem *self = FONT_VIEW_MODEL_ITEM (obj);
 
     g_clear_pointer (&self->font_name, g_free);
+    g_clear_pointer (&self->font_preview_text, g_free);
+    g_clear_pointer (&self->font_description, pango_font_description_free);
     g_clear_object (&self->file);
 
     G_OBJECT_CLASS (font_view_model_item_parent_class)->finalize (obj);
 }
 
+static void
+font_view_model_item_get_property (GObject    *object,
+                                   guint       prop_id,
+                                   GValue     *value,
+                                   GParamSpec *pspec)
+{
+    FontViewModelItem *self = FONT_VIEW_MODEL_ITEM (object);
+
+    switch (prop_id) {
+        case PROP_FONT_NAME:
+            g_value_set_string (value, font_view_model_item_get_font_name (self));
+            break;
+        case PROP_FONT_PREVIEW_TEXT:
+            g_value_set_string (value, font_view_model_item_get_font_preview_text (self));
+            break;
+        default:
+            G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+  }
+}
+
 static void
 font_view_model_item_class_init (FontViewModelItemClass *klass)
 {
     GObjectClass *oclass = G_OBJECT_CLASS (klass);
     oclass->finalize = font_view_model_item_finalize;
+    oclass->get_property = font_view_model_item_get_property;
+
+    properties[PROP_FONT_NAME] =
+        g_param_spec_string ("font-name",
+                             "", "", "",
+                             G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+    properties[PROP_FONT_PREVIEW_TEXT] =
+        g_param_spec_string ("preview-text",
+                             "", "", "",
+                             G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+
+    g_object_class_install_properties (oclass, N_PROPS, properties);
 }
 
 static void
@@ -92,7 +135,7 @@ font_view_model_item_init (FontViewModelItem *self)
 static FontViewModelItem *
 font_view_model_item_new (const gchar *font_name,
                           const gchar *font_preview_text,
-                          const PangoFontDescription *font_description,
+                          PangoFontDescription *font_description,
                           GFile *file,
                           int face_index)
 {
@@ -100,7 +143,7 @@ font_view_model_item_new (const gchar *font_name,
 
     item->font_name = g_strdup (font_name);
     item->font_preview_text = g_strdup (font_preview_text);
-    item->font_description = pango_font_description_copy (font_description);
+    item->font_description = font_description;
     item->file = g_object_ref (file);
     item->face_index = face_index;
 
@@ -148,7 +191,7 @@ font_view_model_has_face (FontViewModel *self, FT_Face face)
     match_name = sushi_get_font_name (face, TRUE);
 
     for (idx = 0; idx < n_items; idx++) {
-        FontViewModelItem *item =
+        g_autoptr (FontViewModelItem) item =
             g_list_model_get_item (G_LIST_MODEL (self->model), idx);
 
         if (g_strcmp0 (item->font_name, match_name) == 0)
@@ -425,9 +468,9 @@ connect_to_fontconfig_updates (FontViewModel *self)
     GtkSettings *settings;
 
     settings = gtk_settings_get_default ();
-    self->fontconfig_update_id =
-        g_signal_connect_swapped (settings, "notify::gtk-fontconfig-timestamp",
-                                  G_CALLBACK (ensure_font_list), self);
+    g_signal_connect_object (settings, "notify::gtk-fontconfig-timestamp",
+                             G_CALLBACK (ensure_font_list), self,
+                             G_CONNECT_SWAPPED);
 }
 
 static void
@@ -487,3 +530,4 @@ font_view_model_get_list_model (FontViewModel *self)
 {
     return G_LIST_MODEL (self->model);
 }
+
